@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use overload
   '""' => \&stringify,
@@ -87,14 +87,14 @@ use overload
 
         atan2 => sub ($$) { goto &atan2 },    # built-in function
 
-        #deg2rad => \&deg2rad,
-        #rad2deg => \&rad2deg,
+        deg2rad => \&deg2rad,
+        rad2deg => \&rad2deg,
                );
 
     my %special = (
-                   exp  => sub (_) { goto &exp },     # built-in function
-                   log  => sub (_) { goto &log },     # built-in function
-                   sqrt => sub (_) { goto &sqrt },    # built-in function
+                   exp  => sub (_) { goto &exp },        # built-in function
+                   log  => sub (_) { goto &log },        # built-in function
+                   sqrt => sub (_) { goto &sqrt },       # built-in function
                    cbrt => \&cbrt,
                    logn => \&logn,
                    root => \&root,
@@ -105,7 +105,7 @@ use overload
         acmp => \&acmp,
         cplx => \&cplx,
 
-        abs => sub (_) { goto &abs },      # built-in function
+        abs => sub (_) { goto &abs },         # built-in function
 
         inv  => \&inv,
         sgn  => \&sgn,
@@ -130,8 +130,6 @@ use overload
                   integer => sub { __PACKAGE__->new($_[0], 0) },
                   float   => sub { __PACKAGE__->new($_[0], 0) };
 
-                #binary  => sub { __PACKAGE__->new(oct($_[0]), 0) };
-
                 # Export the 'i' constant
                 foreach my $pair (['i', i()]) {
                     my $sub = $caller . '::' . $pair->[0];
@@ -177,7 +175,8 @@ use overload
     }
 
     sub unimport {
-        overload::remove_constant('binary', '', 'float', '', 'integer');
+        overload::remove_constant(float   => '',
+                                  integer => '',);
     }
 }
 
@@ -395,7 +394,7 @@ sub exp {
 }
 
 #
-## (a + b*i)^x = exp(log(a+b*i) * x)
+## x^y = exp(log(x) * y)
 #
 
 sub pow {
@@ -408,7 +407,7 @@ sub pow {
 }
 
 #
-## root(a + b*i, x) = (a + b*i)^(1/x)
+## root(x, y) = exp(log(x) / y)
 #
 
 sub root ($$) {
@@ -417,7 +416,7 @@ sub root ($$) {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->pow($y->inv);
+    $x->log->div($y)->exp;
 }
 
 #
@@ -767,12 +766,7 @@ sub atan2 {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    state $i = __PACKAGE__->new(0, 1);
-
-    my $t = $x->mul($i);
-
-    $t->{a} += $y->{a};
-    $t->{b} += $y->{b};
+    my $t = __PACKAGE__->new($y->{a} - $x->{b}, $x->{a} + $y->{b});
 
     $t = $t->div($x->mul($x)->add($y->mul($y))->sqrt)->log;
 
@@ -905,18 +899,6 @@ sub sec ($) {
     $t1;
 }
 
-#
-## asec(a + b*i) = acos(1/(a + b*i))
-#
-
-sub asec ($) {
-    my ($x) = @_;
-
-    $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
-
-    $x->inv->acos;
-}
-
 #
 ## sech(a + b*i) = (2 * exp(a + b*i)) / (exp(2 * (a + b*i)) + 1)
 #
@@ -937,6 +919,18 @@ sub sech ($) {
     $t1->div($t2);
 }
 
+#
+## asec(a + b*i) = acos(1/(a + b*i))
+#
+
+sub asec ($) {
+    my ($x) = @_;
+
+    $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
+
+    $x->inv->acos;
+}
+
 #
 ## asech(a + b*i) = acosh(1/(a + b*i))
 #
@@ -1025,6 +1019,56 @@ sub acsch ($) {
     $x->inv->asinh;
 }
 
+#
+## deg2rad(x) = x / 180 * atan2(0, -abs(x))
+#
+
+sub deg2rad ($) {
+    my ($x) = @_;
+
+    $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
+
+    my $t = __PACKAGE__->new($x->{a} / 180, $x->{b} / 180);
+    my $pi = CORE::atan2(0, -($x->{a} * $x->{a} + $x->{b} * $x->{b}));
+
+    if (!ref($pi)) {
+        $t->{a} *= $pi;
+        $t->{b} *= $pi;
+        return $t;
+    }
+
+    $t->mul($pi);
+}
+
+#
+## rad2deg(x) = x * 180 / atan2(0, -abs(x))
+#
+
+sub rad2deg ($) {
+    my ($x) = @_;
+
+    $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
+
+    my $r = __PACKAGE__->new($x->{a} * 180, $x->{b} * 180);
+    my $t = $x->{a} * $x->{a} + $x->{b} * $x->{b};
+
+    if ($t == 0) {
+        return $r;
+    }
+
+    my $pi = CORE::atan2(0, -$t);
+
+    if (!ref($pi) and $pi != 0) {
+        $r->{a} /= $pi;
+        $r->{b} /= $pi;
+        return $r;
+    }
+
+    $r->div($pi);
+}
+
+########################### MISC FUNCTIONS ###########################
+
 #
 ## real(a + b*i) = a
 #
@@ -1099,8 +1143,8 @@ sub cmp {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    ($x->{a} <=> $y->{a})
-      or ($x->{b} <=> $y->{b});
+    (($x->{a} <=> $y->{a}) // return undef)
+      or (($x->{b} <=> $y->{b}) // return undef);
 }
 
 sub acmp ($$) {
@@ -1118,7 +1162,7 @@ sub lt {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->cmp($y) < 0;
+    ($x->cmp($y) // return undef) < 0;
 }
 
 sub le {
@@ -1127,7 +1171,7 @@ sub le {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->cmp($y) <= 0;
+    ($x->cmp($y) // return undef) <= 0;
 }
 
 sub gt {
@@ -1136,7 +1180,7 @@ sub gt {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->cmp($y) > 0;
+    ($x->cmp($y) // return undef) > 0;
 }
 
 sub ge {
@@ -1145,7 +1189,7 @@ sub ge {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->cmp($y) >= 0;
+    ($x->cmp($y) // return undef) >= 0;
 }
 
 sub stringify {
